@@ -19,14 +19,16 @@ int main(int argc, char *argv[])
     viewer.setSource(QString("qrc:TweedUI/tweedsuit.qml"));
     Notty notty; // Notification object
     viewer.rootContext()->setContextProperty("Notty", &notty); // register notification to Qml
+    viewer.rootContext()->setContextProperty("View", &viewer);
     viewer.setWindowTitle("Tweed Suit");
+    // viewer.showFullScreen();
 
 #if defined(USE_OPENGL)
     QApplication::setGraphicsSystem("opengl");
-    QGLFormat format = QGLFormat::defaultFormat();
-    format.setSampleBuffers(false);
+    // QGLFormat format = QGLFormat::defaultFormat();
+    // format.setSampleBuffers(false);
     QGLWidget *glWidget = new QGLWidget();
-    glWidget->setAutoFillBackground(false);
+    // glWidget->setAutoFillBackground(false);
     viewer.setViewport(glWidget);
 #endif
     viewer.setResizeMode(QDeclarativeView::SizeRootObjectToView);
